@@ -28,6 +28,10 @@ class Base(ABC, BaseModel):
             date: date_to_timestamp
         }
 
+    @classmethod
+    def name(cls) -> str:
+        return cls.__name__
+
     @classmethod
     def new_fields(cls, *args, **kwargs):
         return {}
