@@ -1,5 +1,5 @@
 """
-Module containing common types
+Common types.
 """
 from datetime import date
 from typing import NewType
