@@ -1,8 +1,8 @@
 from enum import Enum
 from typing import Optional, List
-from algoralabs.common.base import Base
 
-from algoralabs.common.enum import FieldType
+from algoralabs.common import FieldType
+from algoralabs.common.base import Base
 
 
 class DatasetDataType(Enum):
@@ -25,15 +25,6 @@ class DatasetSearchRequest(Base):
     data_types: Optional[List[str]]  # TODO make enum
 
 
-class DatasetSummaryResponse(Base):
-    id: str
-    display_name: str
-    logical_name: str
-    description: Optional[str]
-    data_type: str  # TODO make enum
-    tag: str
-
-
 class FieldRequest(Base):
     display_name: str
     logical_name: str
@@ -55,9 +46,3 @@ class FieldGroupRequest(Base):
 class SchemaRequest(Base):
     display_name: str
     logical_name: str
-
-
-class SchemaResponse(Base):
-    id: str
-    display_name: str
-    logical_name: str
