@@ -1,5 +1,5 @@
 """
-Module containing util methods for algoralabs' decorators
+Decorator utilities.
 """
 import dataclasses
 import json
@@ -11,16 +11,16 @@ from algoralabs.common.functions import coalesce_callables, coalesce, dataclass_
 
 def __dataclass_to_json_str(data_cls: dataclasses.dataclass, remove_none: bool) -> str:
     """
-    This method gets all the dataclass fields (i.e. the key value pairs) and builds a json string representation
+    Get all the dataclass fields (i.e. the key value pairs) and build a json string representation.
 
-    NOTE: This method is used by the decorators and is set as the __str__ method for the class being decorated
+    NOTE: This is used by the decorators and is set as the __str__ method for the class being decorated.
 
-    Parameters:
-        data_cls: The dataclass being converted to json
-        remove_none: A flag used to remove key value pairs where the value is None from the json conversion
+    Args:
+        data_cls (dataclass): The dataclass being converted to json
+        remove_none (bool): A flag used to remove key value pairs where the value is None from the json conversion
 
     Returns:
-        A string representation of the dataclass
+        str: A string representation of the dataclass
     """
     data_cls_dict = dataclass_to_dict(data_cls, remove_none)
     return json.dumps(data_cls_dict, indent=4)
@@ -28,15 +28,15 @@ def __dataclass_to_json_str(data_cls: dataclasses.dataclass, remove_none: bool)
 
 def __get_input(default_callable: Callable[[], Any], *args, **kwargs):
     """
-    This method determines the input that is used to populate the class.
+    Determine the input that is used to populate the class.
 
-    Parameters:
-        default_callable: A callable method that returns the input for populating the class
+    Args:
+        default_callable (Callable[[], Any]): A callable method that returns the input for populating the class
         *args: The arg tuple passed to the method
         **kwargs: The keyword dictionary passed to the method
 
     Returns:
-        The input used to populate the class
+        Any: The input used to populate the class
     """
 
     return coalesce_callables(
@@ -47,17 +47,18 @@ def __get_input(default_callable: Callable[[], Any], *args, **kwargs):
 
 
 # TODO: Make the cast recursive to handle nested classes at any depth
-def __attempt_cast(name: str, value: Any, typ: type, exception = CastingError) -> Any:
+def __attempt_cast(name: str, value: Any, typ: type, exception: CastingError = CastingError) -> Any:
     """
-    This method attempts to cast the value in the nam value pair to the desired type
+    Attempt to cast the value in the name-value pair to the desired type. Throw an exception if the casting fails.
 
-    Throws an exception if the casting fails
+    Args:
+        name (str): The name of the variable being cast
+        value (Any): The value to be cast
+        typ (type): The desired type to cast the value too
+        exception (CastingError): The exception type thrown if the casting fails
 
-    Parameters:
-        name: The name of the variable being cast
-        value: The value to be cast
-        typ: The desired type to cast the value too
-        exception (optional): The exception type thrown if the casting fails
+    Returns:
+        Any: Any
     """
     if isinstance(value, typ):
         return value
@@ -91,14 +92,16 @@ def __attempt_cast(name: str, value: Any, typ: type, exception = CastingError) -
 
 def __initialize_data_class(data_cls: dataclasses.dataclass, inp: dict, exception) -> None:
     """
-    This method initializes the dataclasses fields using the input provided
+    Initialize the dataclasses fields using the input provided. Throw an exception if the field value is missing and
+    there is no default present.
 
-    Throws an exception if the field value is missing and there is no default present
-
-    Parameters:
-        data_cls: The class being initialized
-        inp: The input used to initialize the dataclass
+    Args:
+        data_cls (dataclass): The class being initialized
+        inp (dict): The input used to initialize the dataclass
         exception: The error thrown if the dataclass field value is missing
+
+    Returns:
+        None
     """
     for name, field_info in data_cls.__dataclass_fields__.items():
         value = coalesce(inp.get(name, None), getattr(data_cls, name, None), field_info.default)
