@@ -1,27 +1,28 @@
 """
-Module containing algoralabs' configuration decorators
+Configuration decorators.
 """
 import dataclasses
+import os
 from dataclasses import dataclass
 from functools import partial, partialmethod
 from typing import Optional
+
 import pydash
 import yaml
-import os
 
-from algoralabs.decorators.__util import __dataclass_to_json_str, __get_input, __initialize_data_class
 from algoralabs.common.errors import InvalidConfig
+from algoralabs.decorators.__util import __dataclass_to_json_str, __get_input, __initialize_data_class
 
 
 def __load_yaml(file: Optional[str] = None) -> dict:
     """
-    This function loads in a yaml file and returns the yaml represented as a dict
+    Load yaml file and return the yaml represented as a dict.
 
-    Parameters:
-        file: The yaml file location
+    Args:
+        file (Optional[str]): The yaml file location
 
     Returns:
-         The dict representation of the yaml file
+         dict: The dict representation of the yaml file
     """
     if file is None or not os.path.isfile(file):
         return {}
@@ -33,14 +34,17 @@ def __load_yaml(file: Optional[str] = None) -> dict:
 
 def __initializer(data_cls: dataclasses.dataclass, yaml_file: str, prefix: str, *args, **kwargs) -> None:
     """
-    This is the __init__ function loaded in for object decorated as configurations
+    The __init__ function loaded in for object decorated as configurations.
 
-    Parameters:
-         data_cls: Dataclass being initialized
-         yaml_file: file location of the yaml used to populate the configuration class
-         prefix: the prefix used to get the base data from the configuration file
+    Args:
+         data_cls (dataclass): Dataclass being initialized
+         yaml_file (str): File location of the yaml used to populate the configuration class
+         prefix (str): Prefix used to get the base data from the configuration file
          *args: The arg tuple passed to the method
          **kwargs: The keyword dictionary passed to the method
+
+    Returns:
+        None
     """
     yaml_input = __get_input(partial(__load_yaml, file=yaml_file), **kwargs)
     inp: dict = (pydash.get(yaml_input, prefix) or yaml_input)
@@ -55,17 +59,18 @@ def configuration(
         **data_class_args
 ) -> dataclasses.dataclass:
     """
-    A decorator used to turn classes (modeled like dataclasses) to configurations objects
+    A decorator used to turn classes (modeled like dataclasses) to configurations objects.
 
-    Parameters:
-        _cls: The class being decorated
-        yaml_file: The yaml file use to populate the _cls (dataclass)
-        prefix: The prefix in the yaml file used to get the lower level input in the file
+    Args:
+        _cls (object): The class being decorated
+        yaml_file (Optional[str]): The yaml file use to populate the _cls (dataclass)
+        prefix (Optional[str]): The prefix in the yaml file used to get the lower level input in the file
         **data_class_args: keyword args passed to the dataclass constructor
 
     Returns:
-        The updated class with the configuration methods
+        dataclass: The updated class with the configuration methods
     """
+
     def wrap(cls):
         setattr(cls, "__init__", partialmethod(__initializer, yaml_file=yaml_file, prefix=prefix))
         setattr(cls, "__str__", partialmethod(__dataclass_to_json_str, remove_none=True))
@@ -76,4 +81,3 @@ def configuration(
         return wrap
 
     return wrap(_cls)
-
