@@ -1,9 +1,10 @@
 """
-Module containing algoralabs' data decorators
+Data transformation decorators.
 """
 import functools
 import logging
-from typing import Tuple, Dict, Any, Callable, Optional
+from typing import Tuple, Dict, Any, Callable
+
 import pandas as pd
 from requests import Response
 
@@ -35,8 +36,17 @@ def data_request(
         transformer: Callable[[Any], Any] = lambda data: pd.DataFrame(data)
 ) -> Callable:
     """
-    Decorator for processing the response of a REST request
+    Decorator for processing the response of a REST request.
+
+    Args:
+        request (Callable): Function
+        processor (Callable[[Response], Any]): Transform response
+        transformer (Callable[[Any], Any]): Transform data output
+
+    Returns:
+        Callable: Wrapped function
     """
+
     @functools.wraps(request)
     def decorator(f):
         @functools.wraps(f)
@@ -60,8 +70,17 @@ def async_data_request(
         transformer: Callable[[Any], Any] = lambda data: pd.DataFrame(data)
 ):
     """
-    Decorator for processing the response of a async REST request
+    Decorator for processing the response of an asynchronous REST request.
+
+    Args:
+        request (Callable): Function
+        processor (Callable[[Response], Any]): Transform response
+        transformer (Callable[[Any], Any]): Transform data output
+
+    Returns:
+        Callable: Wrapped function
     """
+
     @functools.wraps(request)
     def decorator(f):
         @functools.wraps(f)
