@@ -1,17 +1,18 @@
-from typing import Optional, Dict, Union
+from typing import Optional, Dict, Union, Any
+
 from algoralabs.common.base import Base
 
 
 class DocumentRequest(Base):
     name: str
-    type: str  # TODO make enum
+    type: str
     classification: str
     document: Union[str, Dict]
 
 
 class SearchDocumentRequest(Base):
     name: Optional[str]
-    type: Optional[str]  # TODO make enum
+    type: Optional[str]
     classification: Optional[str]
     is_released: Optional[bool]
 
@@ -21,9 +22,9 @@ class Document(Base):
     parent_pk: str
     original_pk: str
     name: str
-    type: str  # TODO make enum
+    type: str
     classification: str
-    document: Union[str, Dict]
+    document: Union[str, Dict[str, Any]]
     created_by: str
     created_at: int
     updated_by: str
